==> tencentcloud_sdk_python_trdp-3.0.840-py2.py3-none-any.whl: tencentcloud/trdp/v20220726/trdp_client.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.trdp.v20220726 import models


class TrdpClient(AbstractClient):
    _apiVersion = '2022-07-26'
    _endpoint = 'trdp.tencentcloudapi.com'
    _service = 'trdp'


    def EvaluateUserRisk(self, request):
        """用户风险质量接口

        :param request: Request instance for EvaluateUserRisk.
        :type request: :class:`tencentcloud.trdp.v20220726.models.EvaluateUserRiskRequest`
        :rtype: :class:`tencentcloud.trdp.v20220726.models.EvaluateUserRiskResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("EvaluateUserRisk", params, headers=headers)
            response = json.loads(body)
            model = models.EvaluateUserRiskResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)

==> tencentcloud_sdk_python_trdp-3.0.1317-py2.py3-none-any.whl: tencentcloud/trdp/v20220726/trdp_client.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.trdp.v20220726 import models


class TrdpClient(AbstractClient):
    _apiVersion = '2022-07-26'
    _endpoint = 'trdp.tencentcloudapi.com'
    _service = 'trdp'


    def EvaluateUserRisk(self, request):
        """用户风险质量接口

        :param request: Request instance for EvaluateUserRisk.
        :type request: :class:`tencentcloud.trdp.v20220726.models.EvaluateUserRiskRequest`
        :rtype: :class:`tencentcloud.trdp.v20220726.models.EvaluateUserRiskResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("EvaluateUserRisk", params, headers=headers)
            response = json.loads(body)
            model = models.EvaluateUserRiskResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))
